"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpressionExecute = void 0;
const transaction_1 = require("./transaction");
class ExpressionExecute {
    // eslint-disable-next-line no-useless-constructor
    constructor(builder, executor, expressions, helper) {
        this.builder = builder;
        this.executor = executor;
        this.expressions = expressions;
        this.helper = helper;
    }
    // eslint-disable-next-line @typescript-eslint/ban-types
    execute(expression, data, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (expression === undefined || expression === null || expression.trim() === '') {
                yield this.helper.logger.log('expression is empty');
                return null;
            }
            const query = this.builder.build(expression, options);
            return this.executor.execute(query, data === null || data === undefined ? {} : data, options);
        });
    }
    executeList(expressions, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const queries = expressions.map(p => this.builder.build(p, options));
            return this.executor.executeList(queries, options);
        });
    }
    transaction(options, callback) {
        return __awaiter(this, void 0, void 0, function* () {
            this.executor.transaction(options, (transaction) => __awaiter(this, void 0, void 0, function* () {
                const tr = new transaction_1.ExpressionTransaction(transaction, this.builder, this.expressions);
                yield callback(tr);
            }));
        });
    }
}
exports.ExpressionExecute = ExpressionExecute;
//# sourceMappingURL=execute.js.map